Turberfield Utility library — Turberfield utilities guide 0.009.0

# Turberfield utilities guide 0.009.0

## Turberfield Utility library

Turberfield’s mission is to provide a validated Pythonic framework for discrete event simulations and turn-based games.

The API may change significantly as the project proceeds. At this early stage, you should only use the latest release, which may not be compatible with previous versions.

If you’ve spotted a bug in Turberfield, please let me know so I can fix it. If you think Turberfield lacks a feature, you can help drive development by describing your Use Case.

In either event, please leave a message on the project’s message board.

# Turberfield Utility library

Author: | tundish
Copyright: | 2015 D Haynes
Licence: | GNU General Public License

- 1. The `homogeneous` module

- Index
- Module Index